<?php

class ABT_Options  {

    public $citation_styles;

    /**
     * Save the array of citation styles to $this->citation_styles and add a
     *   link to the options page in the admin menu.
     */
    public function __construct() {
        $this->get_citation_styles();
        add_action('admin_menu', [$this, 'add_options_page']);
    }

    /**
     * Grabs the citation styles from the vendor array and saves them to
     *   $this->citation_styles
     */
    private function get_citation_styles() {
        include dirname(__FILE__).'/../../vendor/citationstyles.php';
        $this->citation_styles = $citation_styles;
    }

    /**
     * Sanitizes and saves the path to the custom CSL file.
     *
     * This function should receive a URL and produce a PATH if everything
     *   checks out. Otherwise, it should return an empty string.
     *
     * If the sanitation fails, a dismissable notice is sent to the user.
     * 
     * @param  [string] $url Unsanitized URL submitted with the form.
     * @return [string]      Sanitized PATH to the CSL file.
     */
    private function check_custom_style_url($url) {
        if (file_exists($url) && substr($url, -4) === '.csl') {
            return $url;
        }
        $uploads = wp_upload_dir();
        $file = $uploads['basedir'] . str_replace($uploads['baseurl'], '', $url);
        if (file_exists($file) && substr($file, -4) === '.csl') {
            return $file;
        }
        ?>
        <div class="notice notice-error is-dismissible">
            <p><?php _e('The provided URL is not a valid file in your WordPress upload directory. Please try again.', 'academic-bloggers-toolkit'); ?></p>
        </div>
        <?php
        return '';
    }

    /**
     * Instantiates the options page.
     */
    public function add_options_page() {
        add_options_page(
            "Academic Blogger's Toolkit Options",
            "Academic Blogger's Toolkit",
            'manage_options',
            'abt-options',
            [$this, 'ABT_options_page']
        );
    }

    /**
     * Renders the options page.
     */
    public function ABT_options_page() {

        if (!current_user_can('manage_options')) {
            wp_die('You do not have sufficient permissions to access this page.');
        }

        $abt_options = get_option('abt_options');

        $updated_style_options = isset($_POST['citation_style_options']) ? true : false;
        $updated_custom_css = isset($_POST['custom_css_submit']) ? true : false;
        $updated_display_options = isset($_POST['display_options_submit']) ? true : false;

        if ($updated_style_options) {
            $abt_options['citation_style']['style'] = $_POST['citation_style_style'];
            $abt_options['citation_style']['prefer_custom'] = (bool)$_POST['citation_style_prefer_custom'];
            $abt_options['citation_style']['custom_url'] = $this->check_custom_style_url((string)$_POST['citation_style_custom_url']);
        }
        $citation_style_style = $abt_options['citation_style']['style'];
        $citation_style_prefer_custom = $abt_options['citation_style']['prefer_custom'];
        $citation_style_custom_url = $abt_options['citation_style']['custom_url'];

        if ($updated_custom_css) {
            $abt_options['custom_css'] = stripslashes_deep($_POST['custom_css']);
        }
        $custom_css = isset($abt_options['custom_css']) ? $abt_options['custom_css'] : '';

        if ($updated_display_options) {
            $abt_options['display_options']['bibliography'] = esc_html($_POST['display_options_bibliography']);
            $abt_options['display_options']['links'] = esc_html($_POST['display_options_links']);
            $abt_options['display_options']['bib_heading'] = esc_html($_POST['display_options_bib_heading']);
        }
        $display_options_bibliography = isset($abt_options['display_options']['bibliography']) ? $abt_options['display_options']['bibliography'] : '';
        $display_options_links = isset($abt_options['display_options']['links']) ? $abt_options['display_options']['links'] : '';
        $display_options_bib_heading = isset($abt_options['display_options']['bib_heading']) ? $abt_options['display_options']['bib_heading'] : '';


        update_option('abt_options', $abt_options);
        ?>
		    <div class="wrap"><h2><?php _e("Academic Blogger's Toolkit Options", 'academic-bloggers-toolkit') ?></h2><div id="poststuff"><div id="post-body" class="metabox-holder"><div id="post-body-content"><div class="meta-box-sortables ui-sortable"><div class="postbox"><h3><?php _e('Please send your feedback!', 'academic-bloggers-toolkit') ?></h3><div class="inside"><?php printf(__("If you experience a bug or would like to request a new feature, please visit the <a href='%s' target='_blank'>GitHub Repository</a> and submit an issue. I'll do my best to get it handled in a timely manner. Comments may also be sent to me on twitter ", 'academic-bloggers-toolkit'), 'https://github.com/dsifford/academic-bloggers-toolkit') ?><a href="http://www.twitter.com/flightmed1" target="_blank">@flightmed1</a></div></div><div class="postbox"><h3><?php _e('Default Citation Style', 'academic-bloggers-toolkit') ?></h3><div class="inside"><form method="post" name="citation_style_form"><table style="width: 100%;"><tr><th style="width: 50%;"><label><input type="radio" name="citation_style_prefer_custom" value='' <?php checked($citation_style_prefer_custom, false) ?> /><?php _e('Use a predefined citation style by default', 'academic-bloggers-toolkit') ?></label></th><th style="width: 50%;"><label><input type="radio" name="citation_style_prefer_custom" value='true' <?php checked($citation_style_prefer_custom, true) ?> /><?php _e('Use custom citation style by default ', 'academic-bloggers-toolkit') ?><a href="https://github.com/dsifford/academic-bloggers-toolkit#using-a-custom-citation-style" target="_blank">[?]</a></label></th></tr><tr><td><select id="abt_citation_style" name="citation_style_style" style="width: 100%;" aria-label="select predefined citation style"><?php if ($this->citation_styles) : foreach ($this->citation_styles as $key => $value) : $■['key'] = $key;$■['value'] = $value; ?><option value="<?php echo $value['value'] ?>" <?php selected($citation_style_style, $value['value']); ?>><?php echo $value['label'] ?></option><?php endforeach; endif ?></select></td><td><input type="text" name="citation_style_custom_url" aria-label="url to custom citation style" value="<?php echo $citation_style_custom_url ?>" class="large-text"/></td></tr><tr><td colspan="2" style="text-align: right;"><input type="submit" name="citation_style_options" value="Update" aria-label="Update citation options submit" class="button-primary"/></td></tr></table></form></div></div><div class="postbox"><h3><?php _e('Display Options', 'academic-bloggers-toolkit') ?></h3><div class="inside"><form method="post" name="display_options_form"><table style="width: 100%;"><tr><td style="width: 25%;"><label for="display_options_bibliography"><?php _e('The bibliography should', 'academic-bloggers-toolkit') ?></label></td><td style="width: 75%;"><select name="display_options_bibliography" id="display_options_bibliography" style="width: 100%;"><option value="fixed" <?php selected($display_options_bibliography, 'fixed'); ?>><?php _e('be fixed on the page', 'academic-bloggers-toolkit') ?></option>
<option value="toggle" <?php selected($display_options_bibliography, 'toggle'); ?>><?php _e('toggle on click', 'academic-bloggers-toolkit') ?></option></select></td></tr><tr><td style="width: 25%;"><label for="display_options_links"><?php _e('Clickable links should be included in the bibliography', 'academic-bloggers-toolkit') ?></label></td><td style="width: 75%;"><select name="display_options_links" id="display_options_links" style="width: 100%;"><option value="always" <?php selected($display_options_links, 'always'); ?>><?php _e('whenever possible', 'academic-bloggers-toolkit') ?></option>
<option value="urls" <?php selected($display_options_links, 'urls'); ?>><?php _e('when the citation has a visible URL', 'academic-bloggers-toolkit') ?></option>
<option value="never" <?php selected($display_options_links, 'never'); ?>><?php _e('never', 'academic-bloggers-toolkit') ?></option></select></td></tr><tr><td style="width: 25%;"><label style="white-space: nowrap;" for="display_options_bib_heading"><?php _e('The heading for bibliographies should be', 'academic-bloggers-toolkit') ?></label></td><td style="width: 75%;"><input type="text" name="display_options_bib_heading" id="display_options_bib_heading" value="<?php echo $display_options_bib_heading ?>" class="large-text"/></td></tr><tr><td colspan="2" style="text-align: right;"><input type="submit" name="display_options_submit" value="Update" aria-label="Update display options submit" class="button-primary"/></td></tr></table></form></div></div><div class="postbox"><h3><?php _e('Override CSS', 'academic-bloggers-toolkit') ?></h3><form method="post" name="custom_css_form"><table class="form-table"><tr valign="top"><td scope="row" width="50%"><textarea name="custom_css" cols="80" rows="20" style="font-family: monospace;" aria-label="Textarea for custom CSS" class="large-text"><?php echo $custom_css ?></textarea></td><td width="50%" style="vertical-align: top;"><table><tr><th colspan="2"><?php _e('CSS Selectors used in this plugin', 'academic-bloggers-toolkit') ?></th></tr><tr><td><strong><?php _e('Inline Citations', 'academic-bloggers-toolkit') ?></strong></td><td><code>.abt_cite</code></td></tr><tr><td><strong><?php _e('Citation Tooltips', 'academic-bloggers-toolkit') ?></strong></td><td><code>.abt-tooltip, .abt_tooltip_arrow, .abt_tooltip_touch_close</code></td></tr><tr><td><strong><?php _e('Bibliography', 'academic-bloggers-toolkit') ?></strong></td><td><code>#abt-smart-bib, #abt-smart-bib h3, #abt-smart-bib > div, .abt-url</code></td></tr><tr><td><strong><?php _e('Footnotes', 'academic-bloggers-toolkit') ?></strong></td><td><code>#abt-footnote, .abt-footnote-heading, .abt-footnote-item, .abt-footnote-number</code></td></tr></table></td></tr><tr><td style="font-size: 0.8em; padding-top: 0;"><?php _e('Note: If you are already using a child theme to load CSS, place your CSS overrides there. The box above is only a crutch for those who do not have any custom CSS saved yet. Loading CSS this way is very inefficient.', 'academic-bloggers-toolkit') ?></td><td style="text-align: right"><input type="submit" name="custom_css_submit" value="Update" aria-label="Update custom css submit" class="button-primary"/></td></tr></table></form></div><div class="postbox"><h3><?php _e('How do I', 'academic-bloggers-toolkit') ?>...</h3><div class="inside"><div style="display: flex; flex-wrap: wrap;"><div style="flex: 1; min-width: 300px; padding: 0 5px;"><strong><?php _e('Make my tooltips a different color?', 'academic-bloggers-toolkit') ?></strong><p data-height="300" data-theme-id="dark" data-slug-hash="pboYoZ" data-default-tab="result" data-user="dsifford" data-embed-version="2" class="codepen">See the Pen <a href="http://codepen.io/dsifford/pen/pboYoZ/">pboYoZ</a> by Derek Sifford (<a href="http://codepen.io/dsifford">@dsifford</a>) on <a href="http://codepen.io">CodePen</a>.</p><script async src="//assets.codepen.io/assets/embed/ei.js"></script></div><div style="flex: 1; min-width: 300px; padding: 0 5px;"><strong><?php _e('Apply style to the bibliography list?', 'academic-bloggers-toolkit') ?></strong><p data-height="300" data-theme-id="dark" data-slug-hash="JKjzGj" data-default-tab="result" data-user="dsifford" data-embed-version="2" class="codepen">See the Pen <a href="http://codepen.io/dsifford/pen/JKjzGj/">Bibliography</a> by Derek Sifford (<a href="http://codepen.io/dsifford">@dsifford</a>) on <a href="http://codepen.io">CodePen</a>.</p><script async src="//assets.codepen.io/assets/embed/ei.js"></script></div></div></div></div></div></div></div></div></div>

        <?php

    }
}
new ABT_Options();
